@@ -175,7 +175,7 @@ void Splash()
   mu::console() << _T("  |__|_|  /|____/ |____|    (____  /|__|  /____  > \\___  >|__|    \n");
   mu::console() << _T("        \\/                       \\/            \\/      \\/         \n");
   mu::console() << _T("  Version ") << Parser().GetVersion(pviFULL) << _T("\n");
-  mu::console() << _T("  (C) 2013 Ingo Berg\n");
+  mu::console() << _T("  (C) 2014 Ingo Berg\n");
 }
 
 //---------------------------------------------------------------------------
@@ -473,7 +473,8 @@ void Calc()
   value_type  vVarVal[] = { 1, 2 }; // Values of the parser variables
   parser.DefineVar(_T("a"), &vVarVal[0]);  // Assign Variable names and bind them to the C++ variables
   parser.DefineVar(_T("b"), &vVarVal[1]);
-  parser.DefineStrConst(_T("strBuf"), _T("hello world") );
+  parser.DefineStrConst(_T("sVar1"), _T("Sample string 1") );
+  parser.DefineStrConst(_T("sVar2"), _T("Sample string 2") );
   parser.AddValIdent(IsHexValue);
 
   // Add user defined unary operators
